Plot the posterior probabilities of a haplotype given the refernece panel.
haplotypePainter(
posteriorProbabilities,
title = "",
labelScaling,
numberOfInbreeding = 0
)No return value called for side effects
Posterior probabilities matrix with the size of number of loci by the number of reference strain.
Figure title.
Scaling parameter for plotting.
Number of inbreading strains